==> haskell-ini-0.4.2-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-6TvPVCXreUSIx8neKFhuQP
key:                  ini-0.4.2-6TvPVCXreUSIx8neKFhuQP
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  9bd99cc8238f8d8cf82ab92853a62dc7
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-6TvPVCXreUSIx8neKFhuQP
depends:
    attoparsec-0.14.4-75nKbPMSPaLAG220BErtuR base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-LJBbYvuM7Af6ez80tefkUA

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.4.2-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-KeD1EuARkj4JZfcCMWDnlr
key:                  ini-0.4.2-KeD1EuARkj4JZfcCMWDnlr
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  63da9826471bd5b326aa9832ec3416af
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-KeD1EuARkj4JZfcCMWDnlr
depends:
    attoparsec-0.14.4-ARFIPKVHAQdH6rZ1P31wQY base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-CjV5euINhym8dGoasHPURS

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
